@@ -1,5 +1,5 @@
 import pandas as pd
-import re, os, pkg_resources
+import re, os
 
 class Phonetic_Manipulation():
 	"""
@@ -106,8 +106,9 @@ class Phonetic_Manipulation():
 		pl : list
 			an optional list of phones already found in the data
 		"""
-		phoneset = pkg_resources.resource_stream(__name__, '/data/phoneset_mapping.csv')
-		diacritics = pkg_resources.resource_stream(__name__, '/data/diacritic_mappings.csv')
+
+		phoneset = pkg_resources.resource_stream(__name__, 'data/phoneset_mapping.csv')
+		diacritics = pkg_resources.resource_stream(__name__, 'data/diacritic_mappings.csv')
 
 		self.ps = pd.read_csv(phoneset)
 		self.dm = pd.read_csv(diacritics)
